| Title: | Shiny Gadget for Interactive Viewing and Exploration of Chromatograms |
|---|---|
| Description: | Shiny Gadget for interactive viewing and exploration of chromatograms. |
| Authors: | Ethan Bass [aut, cre] (ORCID: <https://orcid.org/0000-0002-6175-6739>) |
| Maintainer: | Ethan Bass <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.0 |
| Built: | 2026-05-22 09:34:14 UTC |
| Source: | https://github.com/ethanbass/ShinyChromViewer |
Shiny gadget for viewing chromatograms
chrom_viewer(peak_table, chrom_list)chrom_viewer(peak_table, chrom_list)
peak_table |
A |
chrom_list |
A list of chromatograms. |
No return value.
Ethan Bass
data(Sa_warp) data(pk_tab) chrom_viewer(pk_tab)data(Sa_warp) data(pk_tab) chrom_viewer(pk_tab)
Converts chromatograms to long format
convert_chrom(x)convert_chrom(x)
x |
A chromatographic matrix in wide format. |
A chromatographic matrix in long format.
Ethan Bass
Summarizes peak information
summarize_peak_info(peak_table)summarize_peak_info(peak_table)
peak_table |
A |
A peak_table object.
Ethan Bass
Converts list of chromatograms to long format
tidy_chrom_converter(x)tidy_chrom_converter(x)
x |
A list of chromatographic matrices in wide format. |
A list of chromatographic matrices in long format.
Ethan Bass